@@ -4,23 +4,24 @@ g.analyse =  function(I, C, M, IMP, params_247 = c(), params_phyact = c(),
   
   #get input variables
   input = list(...)
-  expectedArgs = c("I", "C", "M", "IMP", "params_247", "params_phyact", 
-                   "params_general", "params_cleaning", "quantiletype",
-                    "myfun")
-  if (any(names(input) %in% expectedArgs == FALSE) |
-      any(!unlist(lapply(expectedArgs, FUN = exists)))) {
-    # Extract and check parameters if user provides more arguments than just the parameter arguments
+  if (length(input) > 0 ||
+      length(params_247) == 0 || length(params_phyact) == 0 ||
+      length(params_general) == 0 || length(params_cleaning) == 0) {
+    # Extract and check parameters if user provides more arguments than just the parameter arguments,
+    # or if params_[...] aren't specified (so need to be filled with defaults).
     # So, inside GGIR this will not be used, but it is used when g.analyse is used on its own
     # as if it was still the old g.analyse function
     params = extract_params(params_247 = params_247,
                             params_phyact = params_phyact,
                             params_general = params_general,
                             params_cleaning = params_cleaning,
-                            input = input) # load default parameters
+                            input = input,
+                            params2check = c("247", "phyact", "general", "cleaning")) # load default parameters
     params_247 = params$params_247
     params_phyact = params$params_phyact
     params_general = params$params_general
     params_cleaning = params$params_cleaning
+    rm(params)
   }
   params_247[["L5M5window"]] = c(0,24) # as of version 1.6-0 this is hardcoded because argument qwindow now
   # specifies the window over which L5M5 analysis is done. So, L5M5window is a depricated
