@@ -131,6 +131,10 @@ g.part3 = function(metadatadir = c(), f0, f1, myfun = c(),
       Ncores2use = min(c(Ncores - 1, params_general[["maxNcores"]], (f1 - f0) + 1))
       if (Ncores2use > 1) {
         cl <- parallel::makeCluster(Ncores2use) # not to overload your computer
+        parallel::clusterExport(cl = cl,
+                                varlist = c(unclass(lsf.str(envir = asNamespace("GGIR"), all = T)),
+                                            "MONITOR", "FORMAT"),
+                                envir = as.environment(asNamespace("GGIR")))
         doParallel::registerDoParallel(cl)
       } else {
         # Don't process in parallel if only one core
