@@ -26,9 +26,18 @@ g.part5.savetimeseries = function(ts, LEVELS, desiredtz, rawlevels_fname,
   # Add invalid day indicator
   mdat$invalid_wakinghours = mdat$invalid_sleepperiod =  mdat$invalid_fullwindow = 100
   wakeup = which(diff(c(mdat$SleepPeriodTime,0)) == -1) + 1 # first epoch of each day
-  if (length(wakeup) > 1) {
-    for (di in 1:(length(wakeup) - 1)) {
-      dayindices = wakeup[di]:(wakeup[di + 1] - 1)
+  if (length(wakeup) > 0) {
+    if (length(wakeup) > 1) {
+      for (di in 1:(length(wakeup) - 1)) {
+        dayindices = wakeup[di]:(wakeup[di + 1] - 1)
+        wake = which(mdat$SleepPeriodTime[dayindices] == 0)
+        sleep = which(mdat$SleepPeriodTime[dayindices] == 1)
+        mdat$invalid_wakinghours[dayindices] = round(mean(mdat$invalidepoch[dayindices[wake]]) * 100, digits = 2)
+        mdat$invalid_sleepperiod[dayindices] = round(mean(mdat$invalidepoch[dayindices[sleep]]) * 100, digits = 2)
+        mdat$invalid_fullwindow[dayindices] = round(mean(mdat$invalidepoch[dayindices]) * 100, digits = 2)
+      }
+    } else {
+      dayindices = 1:nrow(mdat)
       wake = which(mdat$SleepPeriodTime[dayindices] == 0)
       sleep = which(mdat$SleepPeriodTime[dayindices] == 1)
       mdat$invalid_wakinghours[dayindices] = round(mean(mdat$invalidepoch[dayindices[wake]]) * 100, digits = 2)
@@ -37,6 +46,8 @@ g.part5.savetimeseries = function(ts, LEVELS, desiredtz, rawlevels_fname,
     }
     # round acceleration values to 3 digits to reduce storage space
     mdat$ACC = round(mdat$ACC, digits = 3)
+    # round light data to 0 digits to reduce storage space
+    if ("lightpeak" %in% names(mdat)) mdat$lightpeak = round(mdat$lightpeak)
     if (save_ms5raw_without_invalid == TRUE) {
       # Remove days based on data_cleaning_file
       if (length(DaCleanFile) > 0) { 
