@@ -1,15 +1,13 @@
 g.readaccfile = function(filename, blocksize, blocknumber, filequality,
-                         decn, ws, PreviousEndPage = 1, inspectfileobject = c(),
+                         ws, PreviousEndPage = 1, inspectfileobject = c(),
                          PreviousLastValue = c(0, 0, 1), PreviousLastTime = NULL,
                          params_rawdata = c(), params_general = c(), ...) {
   #get input variables
   input = list(...)
-  if (any(names(input) %in% c("filename", "blocksize", "blocknumber",
-                              "filequality",
-                              "decn", "ws", "PreviousEndPage",
-                              "inspectfileobject", "params_rawdata",
-                              "params_general")) == FALSE) {
-    # Extract and check parameters if user provides more arguments than just the parameter arguments
+  if (length(input) > 0 ||
+      length(params_rawdata) == 0 || length(params_general) == 0) {
+    # Extract and check parameters if user provides more arguments than just the parameter arguments,
+    # or if params_[...] aren't specified (so need to be filled with defaults).
     # So, inside GGIR this will not be used, but it is used when g.getmeta is used on its own
     # as if it was still the old g.getmeta function
     params = extract_params(params_rawdata = params_rawdata,
@@ -22,27 +20,13 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
   # the code identifies which accelerometer brand and data format it is
   # blocksize = number of pages to read at once
   # blocknumber = block count relative to beginning of measurement
-  # mon 0 = Other
-  # mon 1 =  GENEA (DEPRECATED)
-  # mon 2 = GENEACtiv
-  # mon 3 = Actigraph
-  # mon 4 = Axivity
-  # mon 5 = Movisens
-  # mon 6 = Verisense
-  
-  # dformat 1 = binary
-  # dformat 2 = csv
-  # dformat 3 = wav (DEPRECATED)
-  # dformat 4 = cwa
-  # dformat 5 = your own adhoc csv format
-  # dformat 6 = gt3x
   # sf = sample frequency (Hertz)
   # ws = large window size (default 3600 seconds)
   
   switchoffLD = 0
   I = inspectfileobject
   mon = I$monc
-  if (mon == 6) mon = 3
+  if (mon == MONITOR$VERISENSE) mon = MONITOR$ACTIGRAPH
   dformat = I$dformc
   sf = I$sf
   
@@ -53,8 +37,8 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
     # The next time (blocknumber > 1) the startpage will be derived from the previous
     # endpage and the blocksize.
     if (blocknumber != 1 & length(PreviousEndPage) != 0) {
-      # if ((mon == 2 & dformat == 1) | dformat == 2) {  # change this line as the csv data do not need to skip one more row (the skip argument in read.csv does not include this row of the dataset)
-      if (mon == 2 & dformat == 1) {
+      # if ((mon == MONITOR$GENEACTIV && dformat == FORMAT$BIN) || dformat == FORMAT$CSV) {  # change this line as the csv data do not need to skip one more row (the skip argument in read.csv does not include this row of the dataset)
+      if (mon == MONITOR$GENEACTIV && dformat == FORMAT$BIN) {
         # only in GENEActiv binary data and for csv format data
         # page selection is defined from start to end (including end)
         startpage = PreviousEndPage + 1
@@ -68,7 +52,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
     endpage = startpage + deltapage
     return(list(startpage = startpage, endpage = endpage))
   }
-  if (mon == 2 & dformat == 1) { # GENEActiv binary non-RDA format
+  if (mon == MONITOR$GENEACTIV && dformat == FORMAT$BIN) {
     startpage = blocksize * (blocknumber - 1) + 1 # GENEActiv starts with page 1
     deltapage = blocksize
     UPI = updatepageindexing(startpage = startpage, deltapage = deltapage,
@@ -107,7 +91,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
       }
     }
     #===============
-  } else if (mon == 3 & dformat == 2) { # Actigraph csv format
+  } else if (mon == MONITOR$ACTIGRAPH && dformat == FORMAT$CSV) {
     headerlength = 10
     #--------------
     startpage = (headerlength + (blocksize * 300 * (blocknumber - 1)))
@@ -125,10 +109,20 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
       on.exit(sink())
       invisible(force(x))
     }
+
+    op <- options(stringsAsFactors = FALSE)
+    on.exit(options(op))
+    options(warn = -1) # turn off warnings
+    suppressWarnings(expr = {decn = g.dotorcomma(filename, dformat, mon,
+                                                 desiredtz = params_general[["desiredtz"]],
+                                                 rmc.dec = params_rawdata[["rmc.dec"]],
+                                                 loadGENEActiv = params_rawdata[["loadGENEActiv"]])}) # detect dot or comma dataformat
+    options(warn = 0) #turn on warnings
+
     testheader =  quiet(as.data.frame(data.table::fread(filename, nrows = 2, skip = 10,
                                                         dec = decn, showProgress = FALSE,
                                                         header = TRUE),
-                                      stringsAsFactors = FALSE))
+                                                        stringsAsFactors = FALSE))
     if (suppressWarnings(is.na(as.numeric(colnames(testheader)[1]))) ==  FALSE) { # it has no header, first value is a number
       freadheader = FALSE
     } else { # it has a header, first value is a character
@@ -163,32 +157,36 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
     } else {
       P = c()
     }
-  } else if (mon == 4 & dformat == 4) { # axivity cwa
+  } else if (mon == MONITOR$AXIVITY && dformat == FORMAT$CWA) {
     if (utils::packageVersion("GGIRread") < "0.3.0") {
-      pass_on_freq_tol = FALSE
-    } else {
-      pass_on_freq_tol = TRUE
-    }
-    apply_readAxivity = function(fname = filename,
-                                 bstart, bend,
-                                 desiredtz = params_general[["desiredtz"]],
-                                 configtz = params_general[["configtz"]],
-                                 interpolationType = params_rawdata[["interpolationType"]],
-                                 pass_on_freq_tol, 
-                                 frequency_tol = params_rawdata[["frequency_tol"]]) {
-      if (pass_on_freq_tol == FALSE) {
-        try(expr = {P = GGIRread::readAxivity(filename = fname, start = bstart, # try to read block first time
+      # ignore frequency_tol parameter
+      apply_readAxivity = function(fname = filename,
+                                   bstart, bend,
+                                   desiredtz = params_general[["desiredtz"]],
+                                   configtz = params_general[["configtz"]],
+                                   interpolationType = params_rawdata[["interpolationType"]],
+                                   frequency_tol = params_rawdata[["frequency_tol"]]) {
+        try(expr = {P = GGIRread::readAxivity(filename = fname, start = bstart,
                                               end = bend, progressBar = FALSE, desiredtz = desiredtz,
                                               configtz = configtz,
                                               interpolationType = interpolationType)}, silent = TRUE)
-      } else {
-        try(expr = {P = GGIRread::readAxivity(filename = filename, start = bstart, # try to read block first time
+        return(P)
+      }
+    } else {
+      # pass on frequency_tol parameter to GGIRread::readAxivity function
+      apply_readAxivity = function(fname = filename,
+                                   bstart, bend,
+                                   desiredtz = params_general[["desiredtz"]],
+                                   configtz = params_general[["configtz"]],
+                                   interpolationType = params_rawdata[["interpolationType"]],
+                                   frequency_tol = params_rawdata[["frequency_tol"]]) {
+        try(expr = {P = GGIRread::readAxivity(filename = filename, start = bstart,
                                               end = bend, progressBar = FALSE, desiredtz = desiredtz,
                                               configtz = configtz,
                                               interpolationType = interpolationType,
                                               frequency_tol = frequency_tol)}, silent = TRUE)
+        return(P)
       }
-      return(P)
     }
     
     startpage = blocksize * (blocknumber - 1)
@@ -196,7 +194,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
     UPI = updatepageindexing(startpage = startpage, deltapage = deltapage,
                              blocknumber = blocknumber, PreviousEndPage = PreviousEndPage, mon = mon, dformat = dformat)
     startpage = UPI$startpage;    endpage = UPI$endpage
-    P = apply_readAxivity(bstart = startpage, bend = endpage, pass_on_freq_tol = pass_on_freq_tol)
+    P = apply_readAxivity(bstart = startpage, bend = endpage)
     if (length(P) > 1) { # data reading succesful
       if (length(P$data) == 0) { # too short?
         P = c() ; switchoffLD = 1
@@ -215,21 +213,21 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
       PtestLastPage = PtestStartPage = NULL
       # Try to read the last page of the block because if it exists then there might be
       # something wrong with the first page(s).
-      PtestLastPage = apply_readAxivity(bstart = endpage, bend = endpage, pass_on_freq_tol = pass_on_freq_tol)
+      PtestLastPage = apply_readAxivity(bstart = endpage, bend = endpage)
       if (length(PtestLastPage) > 1) { 
         # Last page exist, so there must be something wrong with the first page
         NFilePagesSkipped = 0
         while (length(PtestStartPage) == 0) { # Try loading the first page of the block by iteratively skipping a page
           NFilePagesSkipped = NFilePagesSkipped + 1
           startpage = startpage + NFilePagesSkipped
-          PtestStartPage = apply_readAxivity(bstart = startpage, bend = startpage, pass_on_freq_tol = pass_on_freq_tol)
+          PtestStartPage = apply_readAxivity(bstart = startpage, bend = startpage)
           if (NFilePagesSkipped == 10 & length(PtestStartPage) == 0) PtestStartPage = FALSE # stop after 10 attempts
         }
       }
       if (length(PtestStartPage) > 1) {
         # Now we know on which page we can start and end the block, we can try again to
         # read the entire block:
-        P = apply_readAxivity(bstart = startpage, bend = endpage, pass_on_freq_tol = pass_on_freq_tol)
+        P = apply_readAxivity(bstart = startpage, bend = endpage)
         if (length(P) > 1) { # data reading succesful
           if (length(P$data) == 0) { # if this still does not work then
             P = c() ; switchoffLD = 1
@@ -256,7 +254,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
         if (blocknumber == 1) filequality$filecorrupt = TRUE
       }
     }
-  } else if (mon == 4 & dformat == 2) { # axivity (ax3) csv format
+  } else if (mon == MONITOR$AXIVITY && dformat == FORMAT$CSV) {
     freadheader = FALSE
     headerlength = 0
     startpage = (headerlength + (blocksize * 300 * (blocknumber - 1)))
@@ -303,7 +301,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
     } else {
       P = c()
     }
-  } else if (mon == 5 & dformat == 1) { #movisens
+  } else if (mon == MONITOR$MOVISENS && dformat == FORMAT$BIN) {
     startpage = blocksize * (blocknumber - 1) + 1
     deltapage = blocksize
     UPI = updatepageindexing(startpage = startpage, deltapage = deltapage,
@@ -323,15 +321,15 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
       switchoffLD = 1
       filequality$filetooshort = TRUE
     }
-  } else if (mon == 3 & dformat == 6) { #actigraph .gt3x
+  } else if (mon == MONITOR$ACTIGRAPH && dformat == FORMAT$GT3X) {
     startpage = blocksize * (blocknumber - 1) + 1
     deltapage = blocksize
     UPI = updatepageindexing(startpage = startpage, deltapage = deltapage,
                              blocknumber = blocknumber, PreviousEndPage = PreviousEndPage, mon = mon, dformat = dformat)
     startpage = UPI$startpage;    endpage = UPI$endpage
-    try(expr = {P = as.data.frame(read.gt3x::read.gt3x(path = filename, batch_begin = startpage,
+    P = try(expr = {as.data.frame(read.gt3x::read.gt3x(path = filename, batch_begin = startpage,
                                                        batch_end = endpage,asDataFrame = TRUE))}, silent = TRUE)
-    if (length(P) == 0) { # too short or not data at all
+    if (length(P) == 0 | inherits(P, "try-error") == TRUE) { # too short or not data at all
       P = c() ; switchoffLD = 1
       if (blocknumber == 1) filequality$filetooshort = TRUE
       if (blocknumber == 1) filequality$filecorrupt = TRUE
@@ -341,7 +339,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
         if (blocknumber == 1) filequality$filetooshort = TRUE
       } # If data passes these checks then it is usefull
     }
-  } else if (mon == 0 & dformat == 5) { # user specified csv format
+  } else if (mon == MONITOR$AD_HOC && dformat == FORMAT$AD_HOC_CSV) { # user-specified csv format
     startpage = (1 + (blocksize * 300 * (blocknumber - 1)))
     deltapage = (blocksize*300)
     UPI = updatepageindexing(startpage = startpage,deltapage = deltapage,
@@ -365,8 +363,8 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
                                    rmc.dynamic_range = params_rawdata[["rmc.dynamic_range"]],
                                    rmc.unsignedbit = params_rawdata[["rmc.unsignedbit"]],
                                    rmc.origin = params_rawdata[["rmc.origin"]],
-                                   rmc.desiredtz = params_general[["rmc.desiredtz"]],
-                                   rmc.configtz = params_general[["rmc.configtz"]],
+                                   rmc.desiredtz = params_rawdata[["rmc.desiredtz"]],
+                                   rmc.configtz = params_rawdata[["rmc.configtz"]],
                                    rmc.sf = params_rawdata[["rmc.sf"]],
                                    rmc.headername.sf = params_rawdata[["rmc.headername.sf"]],
                                    rmc.headername.sn = params_rawdata[["rmc.headername.sn"]],
@@ -375,6 +373,7 @@ g.readaccfile = function(filename, blocksize, blocknumber, filequality,
                                    rmc.check4timegaps = params_rawdata[["rmc.check4timegaps"]],
                                    rmc.col.wear = params_rawdata[["rmc.col.wear"]],
                                    rmc.doresample = params_rawdata[["rmc.doresample"]],
+                                   rmc.scalefactor.acc = params_rawdata[["rmc.scalefactor.acc"]],
                                    interpolationType = params_rawdata[["interpolationType"]],
                                    PreviousLastValue = PreviousLastValue,
                                    PreviousLastTime = PreviousLastTime,
