@@ -3,8 +3,10 @@ ismovisens = function(data){
         # Is data a directory? Then use the first file to test if recorded with movisens
         directory = dir(data, recursive = T, full.names = T)[1]
         isdir = !is.na(directory)
-        if(isdir == TRUE) data = directory
+        if (isdir == TRUE) data = directory
         # ---------------------------
+        # remove problematic dot at the beginning
+        data = gsub("^./", "", data)
         # Now, I focus on the participant directory
         p_dir = strsplit(data, ".", fixed = T)
         data_tmp = strsplit(p_dir[[1]], "/")
