@@ -24,9 +24,9 @@ test_that("chainof5parts", {
   expect_true(isfilelist(c("file1.bin", "file2.bin")))
   #--------------------------------------------
   # part 1
-  g.part1(datadir = fn, outputdir = getwd(), f0 = 1, f1 = 1,
+  g.part1(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           overwrite = TRUE, desiredtz = desiredtz,
-          studyname = "test", do.enmo = TRUE, do.anglez = TRUE ,do.cal = TRUE,
+          do.enmo = TRUE, do.anglez = TRUE ,do.cal = TRUE,
           windowsizes = c(15,3600,3600), do.parallel = do.parallel,
           minimumFileSizeMB = minimumFileSizeMB, verbose = FALSE)
   expect_true(dir.exists(dn))
@@ -46,29 +46,82 @@ test_that("chainof5parts", {
   g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           idloc = 2, desiredtz = desiredtz, ndayswindow = 1,
           strategy = 3, overwrite = TRUE, hrs.del.start = 0, hrs.del.end = 0,
-          maxdur = Ndays, includedaycrit = 0, do.parallel = do.parallel, myfun = c())
+          maxdur = Ndays, includedaycrit = 0, do.parallel = do.parallel, myfun = c(),
+          verbose = FALSE)
+  dirname = "output_test/meta/ms2.out/"
+  rn = dir(dirname,full.names = TRUE)
+  load(rn[1])
+  load("output_test/meta/basic/meta_123A_testaccfile.csv.RData")
+  expect_equal(nrow(IMP$metashort), 11280)
+  expect_equal(rle(IMP$rout$r4)$lengths[1], 10)
+  expect_equal(rle(IMP$rout$r4)$lengths[3], 13)
+  expect_equal(round(mean(IMP$metashort$ENMO), digits = 5), 0.00802, tolerance = 3)
+  expect_equal(round(as.numeric(SUM$summary$meas_dur_def_proto_day), digits = 3), 1)
+  expect_equal(SUM$summary$`N valid WEdays`, 1)
+  expect_equal(SUM$summary$`N valid WKdays`, 2)
+  # check the ndayswindow included is 24 hours exactly 
+  # ndayswindow = 1 with windowsizes = c(15, 3600, 3600)
+  first_epoch_in_protocol = rle(IMP$rout$r4)$lengths[1] + 1
+  last_epoch_in_protocol = max(which(IMP$rout$r4 == 0))
+  expect_equal(last_epoch_in_protocol - first_epoch_in_protocol + 1,  24)
+  
+  # part 2 with strategy = 3 and hrs.del.start = 6 and hrs.del.end = 6
+  g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
+          idloc = 2, desiredtz = desiredtz, ndayswindow = 1,
+          strategy = 3, overwrite = TRUE, hrs.del.start = 6, hrs.del.end = 6,
+          maxdur = Ndays, includedaycrit = 0, do.parallel = do.parallel, myfun = c(),
+          verbose = FALSE)
   dirname = "output_test/meta/ms2.out/"
   rn = dir(dirname,full.names = TRUE)
   load(rn[1])
   expect_equal(nrow(IMP$metashort), 11280)
-  expect_equal(round(mean(IMP$metashort$ENMO), digits = 5), 0.00802, tolerance = 3)
-  expect_equal(round(as.numeric(SUM$summary$meas_dur_def_proto_day), digits = 3), 1)
-  expect_equal(SUM$summary$`N valid WEdays`, "1")
-  expect_equal(SUM$summary$`N valid WKdays`, "2")
+  expect_equal(rle(IMP$rout$r4)$lengths[1], 16) # removed 6 hours from the ndayswindow at the beginning
+  expect_equal(rle(IMP$rout$r4)$lengths[3], 19) # removed 6 hours from the ndayswindow at the end
+  # check the ndayswindow included is 12 hours exactly (24 minus hrs.del.start/end)
+  # ndayswindow = 1 with windowsizes = c(15, 3600, 3600)
+  first_epoch_in_protocol = rle(IMP$rout$r4)$lengths[1] + 1
+  last_epoch_in_protocol = max(which(IMP$rout$r4 == 0))
+  expect_equal(last_epoch_in_protocol - first_epoch_in_protocol + 1,  12)
   
   # part 2 with strategy = 5
   g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           idloc = 2, desiredtz = desiredtz, ndayswindow = 1,
           strategy = 5, overwrite = TRUE, hrs.del.start = 0, hrs.del.end = 0,
-          maxdur = Ndays, includedaycrit = 0, do.parallel = do.parallel, myfun = c())
+          maxdur = Ndays, includedaycrit = 0, do.parallel = do.parallel, myfun = c(),
+          verbose = FALSE)
   dirname = "output_test/meta/ms2.out/"
   rn = dir(dirname,full.names = TRUE)
   load(rn[1])
   expect_equal(nrow(IMP$metashort), 11280)
+  expect_equal(rle(IMP$rout$r4)$lengths[1], 15)
+  expect_equal(rle(IMP$rout$r4)$lengths[3], 8)
   expect_equal(round(mean(IMP$metashort$ENMO), digits = 5), 0.03398, tolerance = 3)
   expect_equal(round(as.numeric(SUM$summary$meas_dur_def_proto_day), digits = 3), 1)
-  expect_equal(SUM$summary$`N valid WEdays`, "1")
-  expect_equal(SUM$summary$`N valid WKdays`, "2")
+  expect_equal(SUM$summary$`N valid WEdays`, 1)
+  expect_equal(SUM$summary$`N valid WKdays`, 2)
+  # check the ndayswindow included is 24 hours exactly
+  # ndayswindow = 1 with windowsizes = c(15, 3600, 3600)
+  first_epoch_in_protocol = rle(IMP$rout$r4)$lengths[1] + 1
+  last_epoch_in_protocol = max(which(IMP$rout$r4 == 0))
+  expect_equal(last_epoch_in_protocol - first_epoch_in_protocol + 1,  24)
+  
+  # part 2 with strategy = 5 and hrs.del.start = 6 and hrs.del.end = 6
+  g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
+          idloc = 2, desiredtz = desiredtz, ndayswindow = 1,
+          strategy = 5, overwrite = TRUE, hrs.del.start = 6, hrs.del.end = 6,
+          maxdur = Ndays, includedaycrit = 0, do.parallel = do.parallel, myfun = c(),
+          verbose = FALSE)
+  dirname = "output_test/meta/ms2.out/"
+  rn = dir(dirname,full.names = TRUE)
+  load(rn[1])
+  expect_equal(nrow(IMP$metashort), 11280)
+  expect_equal(rle(IMP$rout$r4)$lengths[1], 21) # removed 6 hours from the ndayswindow at the beginning
+  expect_equal(rle(IMP$rout$r4)$lengths[3], 14) # removed 6 hours from the ndayswindow at the end
+  # check the ndayswindow included is 12 hours exactly (24 minus hrs.del.start/end)
+  # ndayswindow = 1 with windowsizes = c(15, 3600, 3600)
+  first_epoch_in_protocol = rle(IMP$rout$r4)$lengths[1] + 1
+  last_epoch_in_protocol = max(which(IMP$rout$r4 == 0))
+  expect_equal(last_epoch_in_protocol - first_epoch_in_protocol + 1,  12)
   
   # part 2 with strategy = 2 and iglevels = 1
   g.part2(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
@@ -103,7 +156,7 @@ test_that("chainof5parts", {
   expect_equal(round(mean(IMP$metashort$ENMO), digits = 5), 0.02911, tolerance = 3)
   expect_that(round(as.numeric(SUM$summary$meas_dur_dys), digits = 5), equals(1.95833))
   expect_that(ncol(SUM$daysummary), equals(34))
-  expect_equal(SUM$daysummary$`p50_ENMO_mg_0-24hr`, c("17.15", "33",  "0"))
+  expect_equal(SUM$daysummary$`p50_ENMO_mg_0-24hr`, c(17.15, 33,  0))
   expect_equal(round(as.numeric(SUM$daysummary$`p90_ENMO_mg_0-24hr`)), c(44, 54, 41), tolerance = 0)
   expect_equal(mean(as.numeric(SUM$daysummary$`M3_ENMO_mg_0-24hr`)), 89.26, tolerance = 3)
   expect_equal(mean(as.numeric(SUM$daysummary$`M3_q40_ENMO_mg_0-24hr`)), 37.383, tolerance = 3)
@@ -139,7 +192,7 @@ test_that("chainof5parts", {
   expect_that(round(nightsummary$number_sib_wakinghours[1], digits = 4), equals(6))
   expect_true(as.logical(nightsummary$acc_available[1]))
   expect_true(as.logical(nightsummary$sleeplog_used[1]))
-  
+
   #--------------------------------------------
   #part 5
   g.part5(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1, desiredtz = desiredtz,
@@ -148,7 +201,7 @@ test_that("chainof5parts", {
           overwrite = TRUE, excludefirstlast = FALSE, do.parallel = do.parallel,
           frag.metrics = "all", save_ms5rawlevels = TRUE,
           part5_agg2_60seconds = TRUE, do.sibreport = TRUE, nap_model = "hip3yr",
-          iglevels = 1)
+          iglevels = 1, timewindow = c("MM", "WW", "OO"))
   sibreport_dirname = "output_test/meta/ms5.outraw/sib.reports"
   expect_true(dir.exists(sibreport_dirname))
   expect_true(file.exists(paste0(sibreport_dirname, "/sib_report_123A_testaccfile_T5A5.csv")))
@@ -161,15 +214,17 @@ test_that("chainof5parts", {
   
   expect_true(dir.exists(dirname))
   expect_true(file.exists(rn[1]))
-  expect_that(nrow(output),equals(3)) # changed because part5 now gives also first and last day
-  expect_that(ncol(output),equals(160)) # changed because intensity gradient now included in the test
+  expect_that(nrow(output),equals(5)) # changed because OO window is exported
+  expect_that(ncol(output),equals(197))
   expect_that(round(as.numeric(output$wakeup[2]), digits = 4), equals(36))
+  expect_that(as.numeric(output$dur_day_spt_min[4]), equals(1150)) # WW window duration
+  expect_that(as.numeric(output$dur_day_spt_min[5]), equals(1680)) # OO window duration
   dirname_raw = "output_test/meta/ms5.outraw/40_100_400"
   rn2 = dir(dirname_raw,full.names = TRUE, recursive = T)
   expect_true(file.exists(rn2[1]))
   TSFILE = read.csv(rn2[1])
   expect_that(nrow(TSFILE),equals(1150))
-  expect_equal(ncol(TSFILE), 11) # 11 columns now because of nap_nonwear classification
+  expect_equal(ncol(TSFILE), 11)
   expect_equal(length(unique(TSFILE$class_id)), 10)
   #GGIR
   suppressWarnings(GGIR(mode = c(2,3,4,5), datadir = fn, outputdir = getwd(),
@@ -187,10 +242,45 @@ test_that("chainof5parts", {
   expect_true(file.exists("output_test/results/part4_nightsummary_sleep_cleaned.csv"))
   expect_true(file.exists("output_test/results/part4_summary_sleep_cleaned.csv"))
   expect_true(file.exists("output_test/results/file summary reports/Report_123A_testaccfile.csv.pdf"))
+  expect_true(file.exists("output_test/results/part5_daysummary_MM_L40M100V400_T5A5.csv"))
+  expect_true(file.exists("output_test/results/part5_daysummary_WW_L40M100V400_T5A5.csv"))
+  expect_true(file.exists("output_test/results/part5_daysummary_OO_L40M100V400_T5A5.csv"))
   dn = "output_test"
   
   #=======================
   # Different variations on part 4:
+  #--------------------------------------------
+  #--------------------------------------------
+  # part 4 with sleepwindowType = TimeInBed and sleepefficiency.metric = 2
+  g.part4(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
+          idloc = 2, loglocation = sleeplog_fn, do.visual = TRUE, outliers.only = FALSE,
+          excludefirstlast = FALSE, criterror = 1, includenightcrit = 0, #nnights = 7,
+          colid = 1, coln1 = 2, relyonguider = FALSE, desiredtz = desiredtz,
+          storefolderstructure = FALSE, overwrite = TRUE,
+          sleepwindowType = "TimeInBed", sleepefficiency.metric = 2)
+  dirname = "output_test/meta/ms4.out/"
+  rn = dir(dirname,full.names = TRUE)
+  load(rn[1])
+  expect_true("sleeplatency" %in% colnames(nightsummary))
+  expect_true("sleepefficiency" %in% colnames(nightsummary))
+  expect_equal(round(nightsummary$sleeplatency[1], 3), 0.171)
+  expect_equal(round(nightsummary$sleepefficiency[1], 3), 0.951)
+  
+  #--------------------------------------------
+  # part 4 with sleepwindowType = TimeInBed and sleepefficiency.metric = 1
+  g.part4(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
+          idloc = 2, loglocation = sleeplog_fn, do.visual = TRUE, outliers.only = FALSE,
+          excludefirstlast = FALSE, criterror = 1, includenightcrit = 0, #nnights = 7,
+          colid = 1, coln1 = 2, relyonguider = FALSE, desiredtz = desiredtz,
+          storefolderstructure = FALSE, overwrite = TRUE,
+          sleepwindowType = "TimeInBed", sleepefficiency.metric = 1)
+  dirname = "output_test/meta/ms4.out/"
+  rn = dir(dirname,full.names = TRUE)
+  load(rn[1])
+  expect_true("sleeplatency" %in% colnames(nightsummary))
+  expect_true("sleepefficiency" %in% colnames(nightsummary))
+  expect_equal(round(nightsummary$sleepefficiency[1], 3), 0.851)
+  
   #--------------------------------------------
   # part 4 without sleeplog
   g.part4(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
@@ -198,7 +288,8 @@ test_that("chainof5parts", {
           excludefirstlast = FALSE, criterror = 1, includenightcrit = 0,
           nnights = 7, colid = 1, coln1 = 2,
           relyonguider = FALSE, desiredtz = desiredtz,
-          storefolderstructure = TRUE, overwrite = TRUE, verbose = FALSE)
+          storefolderstructure = TRUE, overwrite = TRUE, verbose = FALSE,
+          sleepwindowType = "SPT")
   
   dirname = "output_test/meta/ms4.out/"
   rn = dir(dirname,full.names = TRUE)
@@ -318,10 +409,10 @@ test_that("chainof5parts", {
   write.csv(SDF, file = selectdaysfile)
   
   
-  g.part1(datadir = fn, outputdir = getwd(), f0 = 1, f1 = 1,
+  g.part1(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           overwrite = TRUE, desiredtz = desiredtz,
           do.parallel = do.parallel, myfun = myfun,
-          studyname = "test", do.enmo = TRUE, do.anglez = TRUE, do.cal = FALSE,
+          do.enmo = TRUE, do.anglez = TRUE, do.cal = FALSE,
           windowsizes = c(15, 300, 3600),
           chunksize = 2, do.en = TRUE, do.anglex = TRUE, do.angley = TRUE,
           do.roll_med_acc_x = TRUE, do.roll_med_acc_y = TRUE, do.roll_med_acc_z = TRUE,
